@@ -39,8 +39,7 @@ public class NTLMUtilities implements NTLMConstants {
     /**
      * @see #writeSecurityBuffer(short, short, int, byte[], int)
      */
-    public final static byte[] writeSecurityBuffer(short length,
-            int bufferOffset) {
+    public final static byte[] writeSecurityBuffer(short length, int bufferOffset) {
         byte[] b = new byte[8];
         writeSecurityBuffer(length, length, bufferOffset, b, 0);
         return b;
@@ -61,8 +60,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @param b the buffer in which we write the security buffer
      * @param offset the offset at which to write to the b buffer
      */
-    public final static void writeSecurityBuffer(short length, short allocated,
-            int bufferOffset, byte[] b, int offset) {
+    public final static void writeSecurityBuffer(short length, short allocated, int bufferOffset, byte[] b, int offset) {
         ByteUtilities.writeShort(length, b, offset);
         ByteUtilities.writeShort(allocated, b, offset + 2);
         ByteUtilities.writeInt(bufferOffset, b, offset + 4);
@@ -79,8 +77,8 @@ public class NTLMUtilities implements NTLMConstants {
      * @param b the target byte array 
      * @param offset the offset at which to write in the array
      */
-    public final static void writeOSVersion(byte majorVersion,
-            byte minorVersion, short buildNumber, byte[] b, int offset) {
+    public final static void writeOSVersion(byte majorVersion, byte minorVersion, short buildNumber, byte[] b,
+            int offset) {
         b[offset] = majorVersion;
         b[offset + 1] = minorVersion;
         b[offset + 2] = (byte) buildNumber;
@@ -100,11 +98,11 @@ public class NTLMUtilities implements NTLMConstants {
      */
     public final static byte[] getOsVersion() {
         String os = System.getProperty("os.name");
-        
+
         if (os == null || !os.toUpperCase().contains("WINDOWS")) {
             return DEFAULT_OS_VERSION;
         }
-        
+
         byte[] osVer = new byte[8];
 
         // Let's enclose the code by a try...catch in order to
@@ -112,17 +110,16 @@ public class NTLMUtilities implements NTLMConstants {
         // an exception and deal with the special cases.
         try {
             Process pr = Runtime.getRuntime().exec("cmd /C ver");
-            BufferedReader reader = new BufferedReader(
-                    new InputStreamReader(pr.getInputStream()));
+            BufferedReader reader = new BufferedReader(new InputStreamReader(pr.getInputStream()));
             pr.waitFor();
-            
+
             String line;
-        
+
             // We loop as we may have blank lines.
             do {
-                  line = reader.readLine();
+                line = reader.readLine();
             } while ((line != null) && (line.length() != 0));
-            
+
             reader.close();
 
             // If line is null, we must not go any farther
@@ -149,20 +146,18 @@ public class NTLMUtilities implements NTLMConstants {
                 throw new Exception();
             }
 
-            writeOSVersion(Byte.parseByte(tk.nextToken()), Byte
-                    .parseByte(tk.nextToken()), Short.parseShort(tk
-                    .nextToken()), osVer, 0);
+            writeOSVersion(Byte.parseByte(tk.nextToken()), Byte.parseByte(tk.nextToken()),
+                    Short.parseShort(tk.nextToken()), osVer, 0);
         } catch (Exception ex) {
             try {
                 String version = System.getProperty("os.version");
-                writeOSVersion(Byte.parseByte(version.substring(0, 1)),
-                        Byte.parseByte(version.substring(2, 3)), (short) 0,
-                        osVer, 0);
+                writeOSVersion(Byte.parseByte(version.substring(0, 1)), Byte.parseByte(version.substring(2, 3)),
+                        (short) 0, osVer, 0);
             } catch (Exception ex2) {
                 return DEFAULT_OS_VERSION;
             }
         }
-    
+
         return osVer;
     }
 
@@ -177,22 +172,19 @@ public class NTLMUtilities implements NTLMConstants {
      * <code>NTLMConstants.DEFAULT_OS_VERSION</code> is used
      * @return the type 1 message
      */
-    public final static byte[] createType1Message(String workStation,
-            String domain, Integer customFlags, byte[] osVersion) {
+    public final static byte[] createType1Message(String workStation, String domain, Integer customFlags,
+            byte[] osVersion) {
         byte[] msg = null;
 
         if (osVersion != null && osVersion.length != 8) {
-            throw new IllegalArgumentException(
-                    "osVersion parameter should be a 8 byte wide array");
+            throw new IllegalArgumentException("osVersion parameter should be a 8 byte wide array");
         }
 
         if (workStation == null || domain == null) {
-            throw new IllegalArgumentException(
-                    "workStation and domain must be non null");
+            throw new IllegalArgumentException("workStation and domain must be non null");
         }
 
-        int flags = customFlags != null ? customFlags
-                | FLAG_NEGOTIATE_WORKSTATION_SUPPLIED
+        int flags = customFlags != null ? customFlags | FLAG_NEGOTIATE_WORKSTATION_SUPPLIED
                 | FLAG_NEGOTIATE_DOMAIN_SUPPLIED : DEFAULT_FLAGS;
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
@@ -203,15 +195,11 @@ public class NTLMUtilities implements NTLMConstants {
             baos.write(ByteUtilities.writeInt(flags));
 
             byte[] domainData = ByteUtilities.getOEMStringAsByteArray(domain);
-            byte[] workStationData = ByteUtilities
-                    .getOEMStringAsByteArray(workStation);
+            byte[] workStationData = ByteUtilities.getOEMStringAsByteArray(workStation);
 
             int pos = (osVersion != null) ? 40 : 32;
-            baos.write(writeSecurityBuffer((short) domainData.length, pos
-                    + workStationData.length));
-            baos
-                    .write(writeSecurityBuffer((short) workStationData.length,
-                            pos));
+            baos.write(writeSecurityBuffer((short) domainData.length, pos + workStationData.length));
+            baos.write(writeSecurityBuffer((short) workStationData.length, pos));
 
             if (osVersion != null) {
                 baos.write(osVersion);
@@ -240,8 +228,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @return the position where the next security buffer will be written
      * @throws IOException if writing to the ByteArrayOutputStream fails
      */
-    public final static int writeSecurityBufferAndUpdatePointer(
-            ByteArrayOutputStream baos, short len, int pointer)
+    public final static int writeSecurityBufferAndUpdatePointer(ByteArrayOutputStream baos, short len, int pointer)
             throws IOException {
         baos.write(writeSecurityBuffer(len, pointer));
         return pointer + len;
@@ -282,8 +269,7 @@ public class NTLMUtilities implements NTLMConstants {
      * @param securityBufferOffset the offset at which to read the security buffer
      * @return a new byte array holding the data pointed by the security buffer 
      */
-    public final static byte[] readSecurityBufferTarget(
-            byte[] msg, int securityBufferOffset) {
+    public final static byte[] readSecurityBufferTarget(byte[] msg, int securityBufferOffset) {
         byte[] securityBuffer = new byte[8];
 
         System.arraycopy(msg, securityBufferOffset, securityBuffer, 0, 8);
@@ -293,10 +279,10 @@ public class NTLMUtilities implements NTLMConstants {
 
         byte[] secBufValue = new byte[length];
         System.arraycopy(msg, offset, secBufValue, 0, length);
-        
+
         return secBufValue;
     }
-    
+
     /**
      * Extracts the target name from the type 2 message.
      * 
@@ -307,19 +293,18 @@ public class NTLMUtilities implements NTLMConstants {
      * @throws UnsupportedEncodingException if unable to use the 
      * needed UTF-16LE or ASCII charsets 
      */
-    public final static String extractTargetNameFromType2Message(byte[] msg,
-            Integer msgFlags) throws UnsupportedEncodingException {
+    public final static String extractTargetNameFromType2Message(byte[] msg, Integer msgFlags)
+            throws UnsupportedEncodingException {
         // Read the security buffer to determine where the target name
         // is stored and what it's length is
         byte[] targetName = readSecurityBufferTarget(msg, 12);
 
         // now we convert it to a string
-        int flags = msgFlags == null ? extractFlagsFromType2Message(msg)
-                : msgFlags;
+        int flags = msgFlags == null ? extractFlagsFromType2Message(msg) : msgFlags;
         if (ByteUtilities.isFlagSet(flags, FLAG_NEGOTIATE_UNICODE)) {
             return new String(targetName, "UTF-16LE");
         }
-        
+
         return new String(targetName, "ASCII");
     }
 
@@ -331,10 +316,8 @@ public class NTLMUtilities implements NTLMConstants {
      * type 2 message
      * @return the target info
      */
-    public final static byte[] extractTargetInfoFromType2Message(byte[] msg,
-            Integer msgFlags) {
-        int flags = msgFlags == null ? extractFlagsFromType2Message(msg)
-                : msgFlags;
+    public final static byte[] extractTargetInfoFromType2Message(byte[] msg, Integer msgFlags) {
+        int flags = msgFlags == null ? extractFlagsFromType2Message(msg) : msgFlags;
 
         if (!ByteUtilities.isFlagSet(flags, FLAG_NEGOTIATE_TARGET_INFO))
             return null;
@@ -355,11 +338,9 @@ public class NTLMUtilities implements NTLMConstants {
      * @throws UnsupportedEncodingException if unable to use the 
      * needed UTF-16LE or ASCII charsets 
      */
-    public final static void printTargetInformationBlockFromType2Message(
-            byte[] msg, Integer msgFlags, PrintWriter out)
+    public final static void printTargetInformationBlockFromType2Message(byte[] msg, Integer msgFlags, PrintWriter out)
             throws UnsupportedEncodingException {
-        int flags = msgFlags == null ? extractFlagsFromType2Message(msg)
-                : msgFlags;
+        int flags = msgFlags == null ? extractFlagsFromType2Message(msg) : msgFlags;
 
         byte[] infoBlock = extractTargetInfoFromType2Message(msg, flags);
         if (infoBlock == null) {
@@ -369,21 +350,21 @@ public class NTLMUtilities implements NTLMConstants {
             while (infoBlock[pos] != 0) {
                 out.print("---\nType " + infoBlock[pos] + ": ");
                 switch (infoBlock[pos]) {
-                    case 1:
-                        out.println("Server name");
-                        break;
-                    case 2:
-                        out.println("Domain name");
-                        break;
-                    case 3:
-                        out.println("Fully qualified DNS hostname");
-                        break;
-                    case 4:
-                        out.println("DNS domain name");
-                        break;
-                    case 5:
-                        out.println("Parent DNS domain name");
-                        break;
+                case 1:
+                    out.println("Server name");
+                    break;
+                case 2:
+                    out.println("Domain name");
+                    break;
+                case 3:
+                    out.println("Fully qualified DNS hostname");
+                    break;
+                case 4:
+                    out.println("DNS domain name");
+                    break;
+                case 5:
+                    out.println("Parent DNS domain name");
+                    break;
                 }
                 byte[] len = new byte[2];
                 System.arraycopy(infoBlock, pos + 2, len, 0, 2);
@@ -393,8 +374,7 @@ public class NTLMUtilities implements NTLMConstants {
                 out.println("Length: " + length + " bytes");
                 out.print("Data: ");
                 if (ByteUtilities.isFlagSet(flags, FLAG_NEGOTIATE_UNICODE)) {
-                    out.println(new String(infoBlock, pos + 4, length,
-                            "UTF-16LE"));
+                    out.println(new String(infoBlock, pos + 4, length, "UTF-16LE"));
                 } else {
                     out.println(new String(infoBlock, pos + 4, length, "ASCII"));
                 }
@@ -416,19 +396,16 @@ public class NTLMUtilities implements NTLMConstants {
      * @param osVersion the os version of the client
      * @return the type 3 message
      */
-    public final static byte[] createType3Message(String user, String password,
-            byte[] challenge, String target, String workstation,
-            Integer serverFlags, byte[] osVersion) {
+    public final static byte[] createType3Message(String user, String password, byte[] challenge, String target,
+            String workstation, Integer serverFlags, byte[] osVersion) {
         byte[] msg = null;
 
         if (challenge == null || challenge.length != 8) {
-            throw new IllegalArgumentException(
-                    "challenge[] should be a 8 byte wide array");
+            throw new IllegalArgumentException("challenge[] should be a 8 byte wide array");
         }
 
         if (osVersion != null && osVersion.length != 8) {
-            throw new IllegalArgumentException(
-                    "osVersion should be a 8 byte wide array");
+            throw new IllegalArgumentException("osVersion should be a 8 byte wide array");
         }
 
         //TOSEE breaks tests
@@ -443,31 +420,21 @@ public class NTLMUtilities implements NTLMConstants {
             baos.write(NTLM_SIGNATURE);
             baos.write(ByteUtilities.writeInt(MESSAGE_TYPE_3));
 
-            byte[] dataLMResponse = NTLMResponses.getLMResponse(password,
-                    challenge);
-            byte[] dataNTLMResponse = NTLMResponses.getNTLMResponse(password,
-                    challenge);
+            byte[] dataLMResponse = NTLMResponses.getLMResponse(password, challenge);
+            byte[] dataNTLMResponse = NTLMResponses.getNTLMResponse(password, challenge);
 
-            boolean useUnicode = ByteUtilities.isFlagSet(flags,
-                    FLAG_NEGOTIATE_UNICODE);
+            boolean useUnicode = ByteUtilities.isFlagSet(flags, FLAG_NEGOTIATE_UNICODE);
             byte[] targetName = ByteUtilities.encodeString(target, useUnicode);
             byte[] userName = ByteUtilities.encodeString(user, useUnicode);
-            byte[] workstationName = ByteUtilities.encodeString(workstation,
-                    useUnicode);
+            byte[] workstationName = ByteUtilities.encodeString(workstation, useUnicode);
 
             int pos = osVersion != null ? 72 : 64;
-            int responsePos = pos + targetName.length + userName.length
-                    + workstationName.length;
-            responsePos = writeSecurityBufferAndUpdatePointer(baos,
-                    (short) dataLMResponse.length, responsePos);
-            writeSecurityBufferAndUpdatePointer(baos,
-                    (short) dataNTLMResponse.length, responsePos);
-            pos = writeSecurityBufferAndUpdatePointer(baos,
-                    (short) targetName.length, pos);
-            pos = writeSecurityBufferAndUpdatePointer(baos,
-                    (short) userName.length, pos);
-            writeSecurityBufferAndUpdatePointer(baos,
-                    (short) workstationName.length, pos);
+            int responsePos = pos + targetName.length + userName.length + workstationName.length;
+            responsePos = writeSecurityBufferAndUpdatePointer(baos, (short) dataLMResponse.length, responsePos);
+            writeSecurityBufferAndUpdatePointer(baos, (short) dataNTLMResponse.length, responsePos);
+            pos = writeSecurityBufferAndUpdatePointer(baos, (short) targetName.length, pos);
+            pos = writeSecurityBufferAndUpdatePointer(baos, (short) userName.length, pos);
+            writeSecurityBufferAndUpdatePointer(baos, (short) workstationName.length, pos);
 
             /**
             LM/LMv2 Response security buffer 
@@ -482,7 +449,7 @@ public class NTLMUtilities implements NTLMConstants {
 
             // Session Key Security Buffer ??!
             baos.write(new byte[] { 0, 0, 0, 0, (byte) 0x9a, 0, 0, 0 });
-            
+
             baos.write(ByteUtilities.writeInt(flags));
 
             if (osVersion != null) {
